*------------------------------------------------------------------------------
* Options

*Option limrow= 150000;
Option Optcr= 0.05;

*------------------------------------------------------------------------------
* Sets of indices

SET i items /i1*i10/;


*-----------------------------------------------------------------------------
* Parameters

PARAMETERS
benefit(i) benefit for each item /i1 4, i2 5, i3 3, i4 4, i5 5, i6 6, i7 2, i8 3, i9 7, i10 3/
weights(i) weight for each item /i1 4, i2 5, i3 6, i4 7, i5 8, i6 9, i7 10, i8 11, i9 12, i10 13/
volumes(i) volume for each item /i1 20, i2 19, i3 18, i4 17, i5 16, i6 15, i7 14, i8 13, i9 12, i10 11/
capacityVolA knapsack A volume capacity /1000/
capacityWeiA knapsack A weight capacity /300/
capacityVolB knapsack B volume capacity /700/
capacityWeiB knapsack B weight capacity /500/
M huge quantity /1000000/;

*------------------------------------------------------------------------------
* Decision variables

Integer Variables x(i);
Binary Variables A1vsB0, choose1, choose2;
Variables obj;

*------------------------------------------------------------------------------
* Equations

EQUATIONS        TotBenefit,
                 budgetvolA,
                 budgetweiA,
                 budgetvolB,
                 budgetweiB
                 atleastoneoffirst5,
                 atmosttwoofitem9,
                 either1or2,
                 chosen1upperb,
                 chosen1lowerb,
                 chosen2upperb,
                 chosen2lowerb,
                 chosen6if4,
                 chosen6if5;


TotBenefit..             obj =e= sum(i, benefit(i)*x(i));

budgetvolA..             sum(i,volumes(i)*x(i)) =l= capacityVolA + (1 - A1vsB0) * M;
budgetweiA..             sum(i,weights(i)*x(i)) =l= capacityWeiA + (1 - A1vsB0) * M;

budgetvolB..             sum(i,volumes(i)*x(i)) =l= capacityVolB + A1vsB0 * M;
budgetweiB..             sum(i,weights(i)*x(i)) =l= capacityWeiB + A1vsB0 * M;

atleastoneoffirst5..     x('i1') + x('i2') + x('i3') + x('i4') + x('i5') =g= 1;

atmosttwoofitem9..       x('i9') =l= 2;


either1or2..             choose1 + choose2 =e= 1;
chosen1upperb..          x('i1') =l= choose1 * M;
chosen1lowerb..          x('i1') =g= choose1 * 7;
chosen2upperb..          x('i2') =l= choose2 * M;
chosen2lowerb..          x('i2') =g= choose2 * 7;

chosen6if4..             x('i6') =l= x('i4') * M;
chosen6if5..             x('i6') =l= x('i5') * M;

*------------------------------------------------------------------------------
* Model declaration

MODEL KnapsackevolMax /all/ ;


SOLVE KnapsackevolMax maximizing obj using mip;

